Documentation
¶
Index ¶
- Constants
- func Encode(polyline *Polyline) (string, error)
- type Point
- type Polyline
- func CreatePolyline(precision Precision, points []Point) (*Polyline, error)
- func CreatePolyline3D(type3D Type3D, precision2D, precision3D Precision, points []Point) (*Polyline, error)
- func Decode(polyline string) (*Polyline, error)
- func MustCreatePolyline(precision Precision, points []Point) *Polyline
- func MustCreatePolyline3D(type3D Type3D, precision2D, precision3D Precision, points []Point) *Polyline
- type Precision
- type Type3D
Constants ¶
const FormatVersion uint = 1
FlexPolyline specification version
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Polyline ¶
type Polyline struct {
// contains filtered or unexported fields
}
Structure to store FlexPolyline
func CreatePolyline ¶
Creates a two dimensional FlexPolyline
func CreatePolyline3D ¶
func CreatePolyline3D(type3D Type3D, precision2D, precision3D Precision, points []Point) (*Polyline, error)
Creates a three dimensional FlexPolyline
func Decode ¶
Decodes a Polyline from a string following the format specified in https://github.com/heremaps/flexible-polyline/blob/master/README.md
func MustCreatePolyline ¶
Creates a two dimensional FlexPolyline. Panics if arguments are bad.
func MustCreatePolyline3D ¶
func MustCreatePolyline3D(type3D Type3D, precision2D, precision3D Precision, points []Point) *Polyline
Creates a three dimensional FlexPolyline. Panics if arguments are bad.
func (*Polyline) Coordinates ¶
func (*Polyline) Precision2D ¶
func (*Polyline) Precision3D ¶
type Type3D ¶
type Type3D uint8
Whether the third dimension is present and what meaning it has
func GetThirdDimension ¶
Returns the type of the third dimension data, parsing only the header
Click to show internal directories.
Click to hide internal directories.